/*
 * Copyright 2001-2008 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.uddi.v3_service;

import java.rmi.Remote;
import java.rmi.RemoteException;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import org.uddi.api_v3.BindingDetail;
import org.uddi.api_v3.BusinessDetail;
import org.uddi.api_v3.BusinessList;
import org.uddi.api_v3.FindBinding;
import org.uddi.api_v3.FindBusiness;
import org.uddi.api_v3.FindRelatedBusinesses;
import org.uddi.api_v3.FindService;
import org.uddi.api_v3.FindTModel;
import org.uddi.api_v3.GetBindingDetail;
import org.uddi.api_v3.GetBusinessDetail;
import org.uddi.api_v3.GetOperationalInfo;
import org.uddi.api_v3.GetServiceDetail;
import org.uddi.api_v3.GetTModelDetail;
import org.uddi.api_v3.OperationalInfos;
import org.uddi.api_v3.RelatedBusinessesList;
import org.uddi.api_v3.ServiceDetail;
import org.uddi.api_v3.ServiceList;
import org.uddi.api_v3.TModelDetail;
import org.uddi.api_v3.TModelList;

/**
 * This portType defines all of the UDDI inquiry operations. The inquiry API set
 * allows one to locate and obtain detail on entries in a UDDI registry. The
 * Inquiry API provides three forms of query that follow broadly used
 * conventions which match the needs of software traditionally used with
 * registries. Three distinct patterns of inquiry are supported. <a
 * href="http://uddi.org/pubs/uddi-v3.0.2-20041019.htm#_Toc85908076">link</a>
 * <Br> This class was generated by the JAX-WS RI. JAX-WS RI 2.1.5-b03-
 * Generated source version: 2.1
 *
 */
@WebService(name = "UDDI_Inquiry_PortType", targetNamespace = "urn:uddi-org:api_v3_portType")
@SOAPBinding(parameterStyle = SOAPBinding.ParameterStyle.BARE)
@XmlSeeAlso({
    org.uddi.custody_v3.ObjectFactory.class,
    org.uddi.repl_v3.ObjectFactory.class,
    org.uddi.subr_v3.ObjectFactory.class,
    org.uddi.api_v3.ObjectFactory.class,
    org.uddi.vscache_v3.ObjectFactory.class,
    org.uddi.vs_v3.ObjectFactory.class,
    org.uddi.sub_v3.ObjectFactory.class,
    org.w3._2000._09.xmldsig_.ObjectFactory.class,
    org.uddi.policy_v3.ObjectFactory.class,
    org.uddi.policy_v3_instanceparms.ObjectFactory.class
})
public interface UDDIInquiryPortType extends Remote {

    /**
     * The find_binding API is used to find UDDI bindingTemplate elements. The
     * find_binding API call returns a bindingDetail that contains zero or more
     * bindingTemplate structures matching the criteria specified in the
     * argument list.
     *
     * @param body
     *
     * <ul><li> authInfo: This optional argument is an element that contains an
     * authentication token. Registries that wish to restrict who can perform an
     * inquiry typically require authInfo for this call. </li><li> ·
     * categoryBag: This optional argument is a list of category references in
     * the form of keyedReference elements and keyedReferenceGroup structures.
     * When used, the returned bindingDetail for this API will contain elements
     * matching all of the categories passed (logical AND by default).
     * Specifying the appropriate findQualifiers can override this behavior.
     * Matching rules for each can be found in Section 5.1.7 Matching Rules for
     * keyedReferences and keyedReferenceGroups. </li><li> · findQualifiers:
     * This optional collection of findQualifier elements can be used to alter
     * the default behavior of search functionality. See Section 5.1.4 Find
     * Qualifiers, for more information. </li><li> · find_tModel: This argument
     * provides an alternative or additional way of specifying tModelKeys that
     * are to be used to find the bindingTemplate elements. When specified, the
     * find_tModel argument is treated as an embedded inquiry that is performed
     * prior to searching for bindingTemplate elements. The tModelKeys found are
     * those whose tModels match the criteria contained within the find_tModel
     * element. The tModelKeys found are added to the (possibly empty)
     * collection specified by the tModelBag prior to finding qualified
     * bindingTemplates. Note that the authInfo argument to this embedded
     * find_tModel argument is always ignored. Large result set behavior
     * involving the return of a listDescription does not apply within an
     * embedded argument. If the intermediate result set produced is too large,
     * then the overall query will return E_resultSetTooLarge with an indication
     * that the embedded query returned too many results. If an E_unsupported
     * error occurs as part of processing this embedded argument, it is
     * propagated up to the containing (calling) API. </li><li> · listHead: This
     * optional integer value is used to indicate which item SHOULD be returned
     * as the head of the list. The client may request a subset of the matching
     * data by indicating which item in the resultant set constitutes the
     * beginning of the returned data. The use of the listDescription element is
     * mutually exclusive to the use of the truncated attribute that simply
     * indicates a truncated result list in the Inquiry APIs. See Section 5.1.5
     * Use of listDescription, for a detailed description of the listHead
     * argument. </li><li> · maxRows: This optional integer value allows the
     * requesting program to limit the number of results returned. This argument
     * can be used in conjunction with the listHead argument. </li><li> ·
     * serviceKey: This optional uddi_key is used to specify a particular
     * instance of a businessService element in the registered data. Only
     * bindings in the specific businessService data identified by the
     * serviceKey passed are searched. When it is either omitted or specified as
     * empty (i.e., serviceKey=""), this indicates that all businessServices are
     * to be searched for bindings that meet the other criteria supplied without
     * regard to the service that provides them, and "projected" services are
     * suppressed. </li><li> · tModelBag: This collection of tModelKey elements
     * represent in part or in whole the technical fingerprint of the
     * bindingTemplate structures for which the search is being performed. At
     * least one of either a tModelBag or a find_tModel argument SHOULD be
     * supplied, unless a categoryBag based search is being used. </li><li> If a
     * find_tModel argument is specified (see above), it is treated as an
     * embedded inquiry. The tModelKeys returned as a result of this embedded
     * find_tModel argument are used as if they had been supplied in a tModelBag
     * argument. Changing the order of the keys in the collection or specifying
     * the same tModelKey more than once does not change the behavior of the
     * find. * By default, only bindingTemplates that have a technical
     * fingerprint containing all of the supplied tModelKeys match (logical
     * AND). Specifying appropriate findQualifiers can override this behavior so
     * that bindingTemplates with a technical fingerprint containing any of the
     * specified tModelKeys are returned (logical OR). </li></ul>
     * @return returns org.uddi.api_v3.BindingDetail - In the event that no
     * matches were located for the specified criteria, the bindingDetail
     * structure returned is empty (i.e., it contains no bindingTemplate data).
     * This signifies a zero match result. If no arguments are passed, a
     * zero-match result set will be returned.
     *
     * If the number of matches exceeds the value of the maxRows attribute, the
     * result set MAY be truncated. If this occurs, the response contains the
     * attribute "truncated " with the value "true".
     *
     * As an alternative to the truncated attribute, a registry MAY return a
     * listDescription element. See Section 5.1.5 Use of listDescription, for
     * additional information.
     * @throws DispositionReportFaultMessage, RemoteException
     */
    @WebMethod(operationName = "find_binding", action = "find_binding")
    @WebResult(name = "bindingDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public BindingDetail findBinding(
            @WebParam(name = "find_binding", targetNamespace = "urn:uddi-org:api_v3", partName = "body") FindBinding body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The find_business API is used to find UDDI businessEntity elements. The
     * find_business API call returns a businessList that matches the criteria
     * specified in the arguments
     *
     * @param body <h2>Notes</h2>If a tModelBag or find_tModel was used in the
     * search, the resulting serviceInfos structure reflects data only for the
     * businessServices that actually contained a matching bindingTemplate. For
     * more information on serviceInfos, see Section 5.1.12.3 [find_service]
     *
     * Projected services are treated exactly the same as services that are
     * naturally a part of businessEntities unless the suppressProjectedServices
     * findQualifier is specified, in which case they are omitted from the
     * serviceInfos structure returned and are not considered when determining
     * which businesses match the inquiry criteria. In the event that no matches
     * are found for the specified criteria, a businessList structure containing
     * no businessInfos structure is returned. <Br><Br> In the event that no
     * matches were located for the specified criteria, the businessList
     * structure returned is empty (i.e., it contains no businessInfos data).
     * This signifies a zero match result. If no arguments are passed, a
     * zero-match result set will be returned. <Br><Br> In the event of a large
     * number of matches, (as determined by the UDDI node), or if the number of
     * matches exceeds the value of the maxRows attribute, the UDDI node MAY
     * truncate the result set. If this occurs, the businessList will contain
     * the attribute "truncated" with the value "true". <Br><Br> Second level
     * elements (serviceInfos) within the returned businessList will be sorted
     * in the order in which they were saved. <Br><Br> As an alternative to the
     * truncated attribute, a registry MAY return a listDescription element. See
     * Section 5.1.5 Use of listDescription, for additional information.<Br>
     * <ul><li>authInfo: This optional argument is an element that contains an
     * authentication token. Registries that wish to restrict who can perform an
     * inquiry in them typically require authInfo for this call. </li><li> ·
     * categoryBag: This is a list of category references in the form of
     * keyedReference elements and keyedReferenceGroup structures. The returned
     * businessList contains businessInfo elements matching all of the
     * categories passed (logical AND by default). Specifying the appropriate
     * findQualifiers can override this behavior. Matching rules for each can be
     * found in Section 5.1.7 Matching Rules for keyedReferences and
     * keyedReferenceGroups. </li><li> · discoveryURLs: This is a list of
     * discoveryURL structures to be matched against the discoveryURL data
     * associated with registered businessEntity information. To search for URL
     * without regard to useType attribute values, omit the useType attribute or
     * pass it as an empty attribute. If useType values are included, the match
     * occurs only on registered information that matches both the useType and
     * URL value. The returned businessList contains businessInfo structures
     * matching any of the URL's passed (logical OR). </li><li> · identifierBag:
     * This is a list of business identifier references in the form of
     * keyedReference elements. The returned businessList contains businessInfo
     * structures matching any of the identifiers passed (logical OR by
     * default). Specifying the appropriate findQualifiers can override this
     * behavior. Matching rules can be found in Section 5.1.7 Matching Rules for
     * keyedReferences and keyedReferenceGroups. </li><li> · findQualifiers:
     * This collection of findQualifier elements can be used to alter the
     * default behavior of search functionality. See the Section 5.1.4 Find
     * Qualifiers, for more information. </li><li> · find_relatedBusinesses:
     * This argument is an embedded inquiry and limits the search results to
     * those businesses that are related to a specified business in a specified
     * way. The result is comprised of an intersection of the businesses located
     * with this embedded inquiry and the businesses discovered using the
     * remaining inquiry criteria. The standard syntax and arguments for
     * find_relatedBusinesses apply here. Note that the authInfo argument to
     * this embedded find_relatedBusinesses argument is always ignored. Large
     * result set behavior involving the return of a listDescription does not
     * apply within an embedded argument. If the intermediate result set
     * produced is too large, then the overall query will return
     * E_resultSetTooLarge with an indication that the embedded query returned
     * too many results. If an E_unsupported error occurs as part of processing
     * this embedded argument, it is propagated up to the containing (calling)
     * API. See Section 5.1.11 find_relatedBusinesses, for further information.
     * </li><li> · find_tModel: This argument provides an alternative or
     * additional way of specifying tModelKeys that are used to find businesses
     * which have service bindings with specific technical fingerprints as
     * described above for the tModelBag element. When specified, the
     * find_tModel argument is treated as an embedded inquiry that is performed
     * prior to searching for businesses. The tModelKeys found are those whose
     * tModels match the criteria contained within the find_tModel element. The
     * tModelKeys found are added to the (possibly empty) collection specified
     * by the tModelBag prior to finding qualified businesses. Note that the
     * authInfo argument to this embedded find_tModel argument is always
     * ignored. Large result set behavior involving the return of a
     * listDescription does not apply within an embedded argument. If the
     * intermediate result set produced is too large, then the overall query
     * will return E_resultSetTooLarge with an indication that the embedded
     * query returned too many results. If an E_unsupported error occurs as part
     * of processing this embedded argument, it is propagated up to the
     * containing (calling) API. </li><li> · listHead: This optional integer
     * value is used to indicate which item SHOULD be returned as the head of
     * the list. The client may request a subset of the matching data by
     * indicating which item in the resultant set constitutes the beginning of
     * the returned data. The use of the listDescription element is mutually
     * exclusive to the use of the truncated attribute that simply indicates a
     * truncated result list in the Inquiry APIs. See Section 5.1.5 Use of
     * listDescription, for a detailed description of the listHead argument.
     * </li><li> · maxRows: This optional integer value allows the requesting
     * program to limit the number of results returned. This argument can be
     * used in conjunction with the listHead argument. </li><li> · name: This
     * optional collection of string values represents one or more names
     * potentially qualified with xml:lang attributes. Since "exactMatch" is the
     * default behavior, the value supplied for the name argument must be an
     * exact match. If the "approximateMatch" findQualifier is used together
     * with an appropriate wildcard character in the name, then any
     * businessEntity matching this name with wildcards and the other criteria
     * will be referenced in the results. For more on wildcard matching, see
     * Section 5.1.6 About Wildcards. The businessList returned contains
     * businessInfo structures for businesses whose name matches the value(s)
     * passed (lexical-order match – i.e., leftmost in left-to-right languages).
     * If multiple name values are passed, the match occurs on a logical OR
     * basis. Each name MAY be marked with an xml:lang adornment. If a language
     * markup is specified, the search results report a match only on those
     * entries that match both the name value and language criteria. The match
     * on language is a leftmost case-insensitive comparison of the characters
     * supplied. This allows one to find all businesses whose name begins with
     * an "A" and are expressed in any dialect of French, for example. Values
     * which can be passed in the language criteria adornment MUST obey the
     * rules governing the xml:lang data type as defined in Section 3.3.2.3
     * name. </li><li> · tModelBag: Every Web service instance exposed by a
     * registered businessEntity is represented in UDDI by a bindingTemplate
     * contained within the businessEntity. Each bindingTemplate contains a
     * collection of tModel references called its "technical fingerprint" that
     * specifies its type. The tModelBag argument is a collection of tModelKey
     * elements specifying that the search results are to be limited to
     * businesses that expose Web services with technical fingerprints that
     * match.
     *
     * If a find_tModel argument is specified (see above), it is treated as an
     * embedded inquiry. The tModelKeys returned as a result of this embedded
     * find_tModel argument are used as if they had been supplied in a tModelBag
     * argument. Changing the order of the keys in the collection or specifying
     * the same tModelKey more than once does not change the behavior of the
     * find. * By default, only bindingTemplates that contain all of the
     * tModelKeys in the technical fingerprint match (logical AND). Specifying
     * appropriate findQualifiers can override this behavior so that
     * bindingTemplates containing any of the specified tModelKeys match
     * (logical OR). </li></ul>
     * @return returns org.uddi.api_v3.BusinessList This API call returns a
     * businessList on success. This structure contains information about each
     * matching business, including summaries of its businessServices:
     * @throws DispositionReportFaultMessage, RemoteException <br><br>
     *
     */
    @WebMethod(operationName = "find_business", action = "find_business")
    @WebResult(name = "businessList", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public BusinessList findBusiness(
            @WebParam(name = "find_business", targetNamespace = "urn:uddi-org:api_v3", partName = "body") FindBusiness body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     *
     * @param body
     * @return returns org.uddi.api_v3.RelatedBusinessesList
     * @throws DispositionReportFaultMessage, RemoteException
     */
    @WebMethod(operationName = "find_relatedBusinesses", action = "find_relatedBusinesses")
    @WebResult(name = "relatedBusinessesList", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public RelatedBusinessesList findRelatedBusinesses(
            @WebParam(name = "find_relatedBusinesses", targetNamespace = "urn:uddi-org:api_v3", partName = "body") FindRelatedBusinesses body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The find_relatedBusinesses API is used to find businessEntity elements,
     * which have a completed relationship with the specified businessEntity
     * that matches the criteria supplied. The find_relatedBusinesses API call
     * returns a relatedBusinessesList structure containing results that match
     * the criteria specified in the arguments. For additional information on
     * the use of find_relatedBusinesses, refer to Appendix A: Relationships and
     * Publisher Assertions, for more information on business relationships.
     *
     * @param body
     *
     * <ul><li> authInfo: This optional argument is an element that contains an
     * authentication token. Registries that wish to restrict who can perform an
     * inquiry in them typically require authInfo for this call. </li><li>
     * businessKey: This uddi_key is used to specify a particular businessEntity
     * instance to use as the focal point of the search. It MUST NOT be used in
     * conjunction with the fromKey or toKey arguments. It MUST refer to the
     * businessKey of an existing businessEntity in the registry. The result set
     * reports businesses that are related in some way to the businessEntity
     * whose key is specified. </li><li> findQualifiers: This collection of
     * findQualifier elements can be used to alter the default behavior of
     * search functionality. See Section 5.1.4 Find Qualifiers, for more
     * information. </li><li> fromKey: This uddi_key is used to specify a
     * particular businessEntity instance which corresponds to the fromKey of a
     * completed businessRelationship, for use as the focal point of the search.
     * It MUST NOT be used in conjunction with the businessKey or toKey
     * arguments. The result set reports businesses for which a relationship
     * whose fromKey matches the key specified exists. </li><li> keyedReference:
     * This is a single, optional keyedReference element that is used to specify
     * a relationship type, such that only businesses that are related to the
     * focal point in a specific way are included in the results. Specifying a
     * keyedReference only affects whether a business is selected for inclusion
     * in the results. If a business is selected, the results include the full
     * set of completed relationships between it and the focal point. See
     * Appendix A: Relationships and Publisher Assertions, for more information
     * on specifying relationships. Matching rules for the use of
     * keyedReferences are described in Section 5.1.7 Matching Rules for
     * keyedReferences and keyedReferenceGroups, with the exception that
     * keyNames MUST also match if they are non-empty in the search criteria for
     * this API. Omitted keyNames are treated as empty keyNames. </li><li>
     * listHead: This optional integer value is used to indicate which item
     * SHOULD be returned as the head of the list. The client may request a
     * subset of the matching data by indicating which item in the resultant set
     * constitutes the beginning of the returned data. The use of the
     * listDescription element is mutually exclusive to the use of the truncated
     * attribute that simply indicates a truncated result list in the Inquiry
     * APIs. See Section 5.1.5 Use of listDescription, for a detailed
     * description of the listHead argument. </li><li> maxRows: This optional
     * integer value allows the requesting program to limit the number of
     * results returned. This argument can be used in conjunction with the
     * listHead argument. </li><li> toKey: This uddi_key is used to specify a
     * particular businessEntity instance which corresponds to the toKey of an
     * existing businessRelationship, for use as the focal point of the search.
     * It MUST NOT be used in conjunction with the businessKey or fromKey
     * arguments. The result set reports businesses for which a relationship
     * whose toKey matches the key specified exists. </li></ul>
     * @return returns org.uddi.api_v3.ServiceList This API call returns a
     * relatedBusinessesList on success:<br>
     *
     * The value of the direction attribute is determined based on the focal
     * business provided in the query. The focal business is the represented by
     * the key provided as a parameter to the find_relatedBusinesses, specified
     * in the "fromKey", "toKey", or "businessKey" argument.
     *
     * Only the publisher assertions from completed relationships including the
     * focal business contribute to the results of find_relatedBusinesses. If
     * the focal business is specified in the query as the "fromKey" then only
     * those assertions where the focal business is the "fromKey" will
     * contribute to the results. Conversely, if the focal business is specified
     * in the query as the "toKey" then only those assertions where the focal
     * business is the "toKey" will be contribute to the results. And if the
     * focal business is specified as the "businessKey" then assertions where
     * the focal business is either the "toKey" and "fromKey" will contribute to
     * the results. <br><br> The direction attribute is either expressed as
     * "fromKey" or "toKey" depending on the relationship of the business to
     * those returned by the call. <br><br> If the focal business is specified
     * as the fromKey in the find_relatedBusinesses query, the
     * sharedRelationships elements returned will have the direction attribute
     * of fromKey. <br><br> If the focal business is specified as the toKey in
     * the find_relatedBusinesses query, the sharedRelationships elements
     * returned will have the direction attribute of toKey. <br><br> If the
     * focal business is specified as the businessKey in the
     * find_relatedBusinesses query then there may be one or two
     * sharedRelationships, one marked with the fromKey and one marked with the
     * toKey. Publisher assertions specifying the focal business as the
     * "fromKey" will contribute to the sharedRelationships element with a
     * direction of "fromKey". Correspondingly, publisher assertions specifying
     * the focal business as the "toKey" will contribute to the
     * sharedRelationships element with a direction of "toKey". <br><br> The
     * example below depicts that Matt's Garage is related to the focal business
     * (i.e. whose business key is uddi:ws-o-rama-cars.com:be47 and which
     * appeared in the find_relatedBusinesses) by exactly one relationship --
     * the "subsidiary" parent-child relationship -- and that Matt's Garage is a
     * subsidiary of the focal business. In such cases, the direction attribute
     * is set to "fromKey". <br><br> Given the completed relationship resulting
     * from the following publisher assertion: <br><br>
     * &lt;publisherAssertion&gt;<br/>&nbsp;&nbsp;&lt;!--&nbsp;Specify&nbsp;ws-o-rama-cars.com:be47&nbsp;businessKey&nbsp;as&nbsp;fromKey--&gt;<br/>&nbsp;&nbsp;&lt;fromKey&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;uddi:ws-o-rama-cars.com:be47<br/>&nbsp;&nbsp;&lt;/fromKey&gt;<br/>&nbsp;&nbsp;&lt;!--&nbsp;Specify&nbsp;ws-o-rama-cars.com:mattsgarage:be3's&nbsp;businessKey&nbsp;as&nbsp;toKey--&gt;<br/>&nbsp;&nbsp;&lt;toKey&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;uddi:ws-o-rama-cars.com:mattsgarage:be3<br/>&nbsp;&nbsp;&lt;/toKey&gt;<br/>&nbsp;&nbsp;&lt;!--Specify&nbsp;a&nbsp;subsidiary&nbsp;relationship&nbsp;using&nbsp;uddi-org:relationships&nbsp;--&gt;<br/>&nbsp;&nbsp;&lt;keyedReference&nbsp;keyName=&quot;Subsidiary&quot;<br/>&nbsp;&nbsp;&nbsp;&nbsp;keyValue=&quot;parent-child&quot;<br/>&nbsp;&nbsp;&nbsp;&nbsp;tModelKey=&quot;uddi:uddi.org:relationships&quot;/&gt;<br/>&lt;/publisherAssertion&gt;<br/>
     * <br><br> and the following find_relatedBusinesses query: <br><br>
     * &lt;find_relatedBusinesses&nbsp;xmlns=&quot;urn:uddi-org:api_v3&quot;&gt;<br/>&lt;businessKey&gt;uddi:ws-o-rama-cars.com:be47&lt;/businessKey&gt;<br/>&lt;/find_relatedBusinesses&gt;<br/>
     * <br><br> the following relatedBusinessList will be returned: <br><br>
     * &lt;relatedBusinessesList&nbsp;operator=&quot;uddi.someoperator&quot;&nbsp;truncated=&quot;false&quot;&nbsp;xmlns=&quot;urn:uddi-org:api_v3&quot;&gt;<br/>&lt;businessKey&gt;uddi:ws-o-rama-cars.com:be47&lt;/businessKey&gt;<br/>&nbsp;&nbsp;&nbsp;&lt;relatedBusinessInfos&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;relatedBusinessInfo&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;businessKey&gt;uddi:ws-o-rama-cars.com:mattsgarage:be3&lt;/businessKey&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;name&gt;Matt's&nbsp;Garage&lt;/name&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;description&gt;Car&nbsp;services&nbsp;in&nbsp;&#x2026;&lt;/description&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;sharedRelationships&nbsp;direction=&quot;fromKey&quot;&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;keyedReference&nbsp;tModelKey=&quot;uddi:uddi.org:relationships&quot;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;keyName=&quot;Subsidiary&quot;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;keyValue=&quot;parent-child&quot;&gt;<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&#x2026;]<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;[&#x2026;]
     * <br><br> In a relatedBusinessInfo with two sharedRelationships elements
     * the sharedRelationships element with direction attribute value of
     * "fromKey" precedes the one with the value of "toKey". The keyedReference
     * elements in the sharedRelationships element will be sorted by last date
     * change of the corresponding publisher assertion in ascending order.
     * <br><br> A publisherAssertion structure is only returned if it contains a
     * signature and it has the following syntax: <br><br> In the event that no
     * matches were located for the specified criteria, the
     * relatedBusinessesList structure returned does not contain a
     * relatedBusinessInfos element. This signifies zero matches. <br><br> In
     * the event of a large number of matches (as determined by the node), or if
     * the number of matches exceeds the value of the maxRows attribute, the
     * node MAY truncate the result set. When this occurs, the
     * relatedBusinessesList contains the attribute "truncated" with the value
     * of this attribute set to "true". <br><br> As an alternative to use of the
     * truncated attribute, a registry MAY return a listDescription element. See
     * Section 5.1.5 Use of listDescription, for additional information.
     * @throws DispositionReportFaultMessage, RemoteException
     */
    @WebMethod(operationName = "find_service", action = "find_service")
    @WebResult(name = "serviceList", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public ServiceList findService(
            @WebParam(name = "find_service", targetNamespace = "urn:uddi-org:api_v3", partName = "body") FindService body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The find_tModel API is used to find UDDI tModel elements. The find_tModel
     * API call returns a list of tModel entries that match a set of specific
     * criteria. The response consists of summary information about registered
     * tModel data returned in a tModelList structure.
     *
     * @param body <p class="MsoBodyText"
     * style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol"><span style="font:7.0pt &quot;Times New
     * Roman&quot;"> </span></span><b><i>authInfo</i></b>: This optional
     * argument is an element that contains an authentication token.&nbsp;
     * Registries that wish to restrict who can perform an inquiry in them
     * typically require authInfo for this call.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>categoryBag</i></b>: This is a list of category
     * references.&nbsp; The returned tModelList contains tModelInfo elements
     * whose associated tModels match all of the categories passed (logical AND
     * by default).&nbsp;&nbsp; Specifying the appropriate findQualifiers can
     * override this behavior.&nbsp; Matching rules for the use of
     * keyedReferences and keyedReferenceGroups are described in Section <a
     * href="#_Ref4225518 ">5.1.7</a> <i>Matching Rules for keyedReferences and
     * keyedReferenceGroups</i>.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>findQualifiers</i></b>: This collection of
     * findQualifier elements is used to alter the default behavior of search
     * functionality.&nbsp; See Section <a href="#_Ref535479804 ">5.1.4</a>
     * <i>Find Qualifiers </i>for more information.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>identifierBag</i></b> This is a list of identifier
     * references in the form of keyedReference elements. The returned
     * tModelList contains tModelInfo elements whose associated tModels match
     * any of the identifiers passed (logical OR by default). Specifying the
     * appropriate findQualifiers can override this behavior.&nbsp; Matching
     * rules are described in Section <a href="#_Ref4225518 ">5.1.7</a>
     * <i>Matching Rules for keyedReferences and keyedReferenceGroups</i>.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>listHead</i></b>:&nbsp; This optional integer value
     * is used to indicate which item SHOULD be returned as the head of the
     * list.&nbsp;&nbsp; The client may request a subset of the matching data by
     * indicating which item in the resultant set constitutes the beginning of
     * the returned data.&nbsp; The use of the listDescription element is
     * mutually exclusive to the use of the truncated attribute that simply
     * indicates a truncated result list in the Inquiry APIs. See Section <a
     * href="#_Ref534886163 ">5.1.5</a> <a href="#_Ref534886163 ">Use of
     * listDescription</a>, for a detailed description of the listHead
     * argument.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>maxRows</i></b>: This optional integer value allows
     * the requesting program to limit the number of results returned. This
     * argument can be used in conjunction with the listHead argument.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>name</i></b><b>:&nbsp; </b>This string value&nbsp;
     * represents the name of the tModel elements to be found.&nbsp; Since
     * tModel data only has a single name, only a single name may be
     * passed.&nbsp; The argument must match exactly since "exactMatch" is the
     * default behavior, but if the "approximateMatch" findQualifier is used
     * together with the appropriate wildcard character, then matching is done
     * according to wildcard rules. See Section <a href="#_Ref4225770
     * ">5.1.6</a> <i>About Wildcards</i> for additional information.&nbsp; The
     * name MAY be marked with an xml:lang adornment.&nbsp; If a language markup
     * is specified, the search results report a match only on those entries
     * that match both the name value and language criteria. The match on
     * language is a leftmost case-insensitive comparison of the characters
     * supplied. This allows one to find all tModels whose name begins with an
     * "A" and are expressed in any dialect of French, for example.&nbsp; Values
     * which can be passed in the language criteria adornment MUST obey the
     * rules governing the xml:lang data type as defined in Section <a
     * href="#_Ref8977786 ">3.3.2.3</a> <i>name</i>.</p>
     * @return returns org.uddi.api_v3.TModelList * <p class="MsoBodyText">In
     * the event that no matches were located for the specified criteria, the
     * tModelList returned will not contain a&nbsp; tModelInfos element.&nbsp;
     * This signifies zero matches.&nbsp; If no arguments are passed, a
     * zero-match result is returned.</p>
     *
     * <p class="MsoBodyText">In the event of a large number of matches (as
     * determined by the node), or if the number of matches exceeds the value of
     * the maxRows attribute, the result set MAY be truncated.&nbsp; When this
     * occurs, the tModelList contains the attribute "truncated" with the value
     * "true".</p>
     *
     * <p class="MsoBodyText">As an alternative to the truncated attribute, a
     * registry MAY return a listDescription element. See Section <a
     * href="#_Ref534886163 ">5.1.5</a> <i>Use of listDescription</i> for
     * additional information. </p>
     * @throws DispositionReportFaultMessage, RemoteException <p
     * class="MsoBodyText">f any error occurs in processing this API call, a
     * dispositionReport element is returned to the caller within a SOAP
     * Fault.&nbsp; In addition to the errors common to all APIs, the following
     * error information is relevant here:</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_invalidCombination</b>: signifies that conflicting
     * findQualifiers have been specified.&nbsp; The error text clearly
     * identifies the findQualifiers that caused the problem.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_invalidKeyPassed</b>: signifies that the uddi_key
     * value passed did not match with any known&nbsp; tModelKey values.&nbsp;
     * The error structure signifies the condition that occurred and the error
     * text clearly calls out the offending key.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_unsupported</b>: signifies that one of the
     * findQualifier values passed was invalid.&nbsp; The invalid qualifier is
     * clearly indicated in the error text.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_resultSetTooLarge</b>: signifies that the node deems
     * that a result set from an inquiry is too large and does not honor
     * requests to obtain the results for this inquiry, even using
     * subsets.&nbsp; The inquiry that triggered this error SHOULD be refined
     * and re-issued.</p>
     */
    @WebMethod(operationName = "find_tModel", action = "find_tModel")
    @WebResult(name = "tModelList", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public TModelList findTModel(
            @WebParam(name = "find_tModel", targetNamespace = "urn:uddi-org:api_v3", partName = "body") FindTModel body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The get_bindingDetail API call returns the bindingTemplate structure
     * corresponding to each of the bindingKey values specified.
     *
     * @param body <p class="MsoBodyText"
     * style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>authInfo</i></b>: This optional argument is an
     * element that contains an authentication token.&nbsp; Registries that wish
     * to restrict who can perform an inquiry in them typically require authInfo
     * for this call.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>bindingKey</i></b>: One or more uddi_key values that
     * represent the UDDI assigned keys for specific instances of registered
     * bindingTemplate data.</p>
     * @return returns org.uddi.api_v3.BindingDetail <p class="MsoBodyText">This
     * API call returns a bindingDetail on successful match of the specified
     * bindingKey values.&nbsp; See Section <a href="#_Ref534884970
     * ">5.1.9.3</a> <i>[find_binding] Returns</i> for information on this
     * structure.&nbsp; If multiple bindingKey values were passed, the results
     * are returned in the same order as the keys passed.</p>
     *
     * <p class="MsoBodyText">If a large number of keys are passed, the node MAY
     * truncate the result set.&nbsp; When this occurs, the bindingDetail result
     * contains the attribute "truncated<i>"</i> with the value "true<i>"</i>.
     * </p>
     *
     * <p class="MsoBodyText">A node MUST NOT return a listDescription element
     * as part of the bindingDetail in response to this API call.</p>
     * @throws DispositionReportFaultMessage, RemoteException If any error
     * occurs in processing this API call, a dispositionReport structure is
     * returned to the caller in a SOAP Fault. In addition to the errors common
     * to all APIs, the following error information is relevant here:
     *
     * · E_invalidKeyPassed: signifies that one of the uddi_key values passed
     * did not match with any known bindingKey key values. No partial results
     * are returned – if any bindingKey values passed are not valid bindingKey
     * values, this error is returned. The error text clearly calls out the
     * offending key.
     */
    @WebMethod(operationName = "get_bindingDetail", action = "get_bindingDetail")
    @WebResult(name = "bindingDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public BindingDetail getBindingDetail(
            @WebParam(name = "get_bindingDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body") GetBindingDetail body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The get_businessDetail API call returns the businessEntity structure
     * corresponding to each of the businessKey values specified.
     *
     * @param body <p class="MsoBodyText"
     * style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>authInfo</i></b><i>: </i>&nbsp;This optional argument
     * is an element that contains an authentication token.&nbsp; Registries
     * that wish to restrict who can perform an inquiry in them typically
     * require authInfo for this call.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>businessKey</i></b>: One or more uddi_key values that
     * represent specific instances of known businessEntity data.</p>
     * @return returns org.uddi.api_v3.BusinessDetail <p class="MsoBodyText">If
     * multiple businessKey values were passed, the results MUST be returned in
     * the same order as the keys passed.</p>
     *
     * <p class="MsoBodyText">If a large number of keys are passed, a node MAY
     * truncate the result set.&nbsp; When this occurs, the businessDetail
     * response contains the attribute "truncated " with the value "true".</p>
     *
     * <p class="MsoBodyText">businessEntity elements retrieved with
     * get_businessDetail can contain service projections. Such projected
     * services appear in full in the businessEntity in which they occur.
     * Projected services can be distinguished from the services that are
     * naturally contained in the businessEntity in which they appear by their
     * businessKey. Services naturally contained in the businessEntity have the
     * businessKey of the businessEntity in which they appear. Projected
     * services have the businessKey of the businessEntity of which they are a
     * natural part.</p>
     * @throws DispositionReportFaultMessage, RemoteException <p
     * class="MsoBodyText">If any error occurs in processing this API call, a
     * dispositionReport element is returned to the caller within a SOAP
     * Fault.&nbsp;&nbsp; In addition to the errors common to all APIs, the
     * following error information is relevant here:</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_invalidKeyPassed</b>: signifies that one of the
     * uddi_key values passed did not match with any known businessKey
     * values.&nbsp; No partial results are returned – if any businessKey values
     * passed are not valid, this error is returned.&nbsp; The error text
     * clearly calls out the offending key.</p>
     */
    @WebMethod(operationName = "get_businessDetail", action = "get_businessDetail")
    @WebResult(name = "businessDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public BusinessDetail getBusinessDetail(
            @WebParam(name = "get_businessDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body") GetBusinessDetail body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The get_operationalnfo API call is used to retrieve entity level
     * operational information (such as the date and time that the data
     * structure was created and last modified, the identifier of the UDDI node
     * at which the entity was published and the identity of the publisher)
     * pertaining to one or more entities. The get_operationalInfo API call
     * returns an operationalInfos structure corresponding to each of the
     * entityKey values specified.
     *
     * @param body <p class="MsoBodyText"
     * style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>authInfo</i></b><i>: </i>&nbsp;This optional argument
     * is an element that contains an authentication token.&nbsp;&nbsp;
     * Registries that wish to restrict who can perform an inquiry in them
     * typically require authInfo for this call.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>entityKey</i></b>: One or more uddi_key values that
     * represent businessEntity, businessService, bindingTemplate or
     * tModelKeys.</p>
     * @return returns org.uddi.api_v3.OperationalInfos This API returns an
     * operationalInfos structure that contains an operationalInfo element for
     * each entity requested by the inquirer.
     * @throws DispositionReportFaultMessage, RemoteException <p
     * class="MsoBodyText">If any error occurs in processing this API call, a
     * dispositionReport element is returned to the caller within a SOAP
     * Fault.&nbsp; In addition to the errors common to all APIs, the following
     * error information is relevant here:</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_invalidKeyPassed</b>: signifies that one of the
     * uddi_key values passed did not match with any known entityKey
     * values.&nbsp; No partial results are returned – if any entityKey values
     * passed are not valid, this error is returned.&nbsp; The error text
     * clearly calls out the offending key(s).</p>
     */
    @WebMethod(operationName = "get_operationalInfo", action = "get_operationalInfo")
    @WebResult(name = "operationalInfos", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public OperationalInfos getOperationalInfo(
            @WebParam(name = "get_operationalInfo", targetNamespace = "urn:uddi-org:api_v3", partName = "body") GetOperationalInfo body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The get_serviceDetail API call returns the businessService structure
     * corresponding to each of the serviceKey values specified.
     *
     * @param body <p class="MsoBodyText"
     * style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>authInfo</i></b><i>: </i>&nbsp;This optional argument
     * is an element that contains an authentication token.&nbsp;&nbsp;
     * Registries that wish to restrict who can perform an inquiry in them
     * typically require authInfo for this call.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>serviceKey</i></b>: One or more uddi_key values that
     * represent UDDI assigned serviceKey values of specific instances of known
     * businessService data.</p>
     * @return returns org.uddi.api_v3.ServiceDetail This API call returns a
     * serviceDetail on successful match of the specified serviceKey values. <p
     * class="MsoBodyText">If multiple serviceKey values were passed, the
     * results will be returned in the same order as the keys passed.</p>
     *
     * <p class="MsoBodyText">If a large number of keys are passed, a node MAY
     * truncate the result set.&nbsp; When this occurs, the response contains
     * the attribute "truncated" with the value "true".</p>
     * @throws DispositionReportFaultMessage, RemoteException <p
     * class="MsoBodyText">If any error occurs in processing this API call, a
     * dispositionReport element is returned to the caller within a SOAP
     * Fault.&nbsp; In addition to the errors common to all APIs, the following
     * error information is relevant here:</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_invalidKeyPassed</b>: signifies that one of the
     * uddi_key values passed did not match with any known serviceKey
     * values.&nbsp; No partial results are returned – if any serviceKey values
     * passed are not valid, this error is returned.&nbsp; The error text
     * clearly calls out the offending key.</p>
     */
    @WebMethod(operationName = "get_serviceDetail", action = "get_serviceDetail")
    @WebResult(name = "serviceDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public ServiceDetail getServiceDetail(
            @WebParam(name = "get_serviceDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body") GetServiceDetail body)
            throws DispositionReportFaultMessage, RemoteException;

    /**
     * The get_tModelDetail API call returns the tModel structure, corresponding
     * to each of the tModelKey values specified.
     *
     * @param body <p class="MsoBodyText"
     * style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>authInfo</i></b>: This optional argument is an
     * element that contains an authentication token.&nbsp; Registries that wish
     * to restrict who can perform an inquiry in them typically require authInfo
     * for this call.</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b><i>tModelKey</i></b>: One or more uddi_key values that
     * represent UDDI assigned tModelKey values of specific instances of known
     * tModel data.</p>
     * @return returns org.uddi.api_v3.TModelDetail This API call returns a
     * tModelDetail on successful match of the specified tModelKey values. <p
     * class="MsoBodyText">If multiple tModelKey values were passed, the results
     * are returned in the same order as the keys passed.</p>
     *
     * <p class="MsoBodyText">If a large number of keys are passed, a node MAY
     * truncate the result set.&nbsp; When this occurs, the response contains
     * the attribute "truncated" with the value of "true".</p>
     * @throws DispositionReportFaultMessage, RemoteException <p
     * class="MsoBodyText">If any error occurs in processing this API call, a
     * dispositionReport structure is returned to the caller in a SOAP
     * Fault.&nbsp; In addition to the errors common to all APIs, the following
     * error information is relevant here:</p>
     *
     * <p class="MsoBodyText" style="margin-left:1.0in;text-indent:-.25in"><span
     * style="font-family:Symbol">·<span style="font:7.0pt &quot;Times New
     * Roman&quot;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
     * </span></span><b>E_invalidKeyPassed</b>: signifies that one of the
     * uddi_key values passed did not match with any known tModelKey
     * values.&nbsp; No partial results are returned – if any tModelKey values
     * passed are not valid, this error is returned.&nbsp; The error text
     * clearly calls out the offending key.</p>
     *
     * <span
     * style="font-size:10.0pt;font-family:Arial;letter-spacing:-.25pt"></span>
     */
    @WebMethod(operationName = "get_tModelDetail", action = "get_tModelDetail")
    @WebResult(name = "tModelDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body")
    public TModelDetail getTModelDetail(
            @WebParam(name = "get_tModelDetail", targetNamespace = "urn:uddi-org:api_v3", partName = "body") GetTModelDetail body)
            throws DispositionReportFaultMessage, RemoteException;
}
